radir-package: Inverse regression model for radiation biodosimetry

radir-packageR Documentation

Inverse regression model for radiation biodosimetry

Description

The package implements a new inverse regression model with applications to radiation biodosimetry.

Details

Package: radir
Type: Package
Version: 1.0.5
Date: 2026-07-27
License: GPL version 2 or newer
LazyLoad: yes

The package implements a new inverse regression model with applications to radiation biodosimetry by means of the function dose.distr. It allows for several distributions for the dose prior including uniform and gamma, and for the mean prior, including gamma and normal distributions. A summary containing the most relevant information about the estimated doses can be obtained via summary and graphics can be obtained in a standard way by means of plot or lines functions.

Author(s)

David Moriña Soler (Universitat Autònoma de Barcelona), Manuel Higueras (Universidad de La Rioja) and Pedro Puig (Universitat Autònoma de Barcelona)

Mantainer: David Moriña Soler <david.morina@uab.cat>

References

Higueras M, Puig P, Ainsbury EA, Rothkamm K. A new inverse regression model applied to radiation biodosimetry. Proc R Soc A 2015;471, http://dx.doi.org/10.1098/rspa.2014.0588

See Also

dose.distr

Examples

f <- expression(b1*x+b2*x^2)
pars <- c("b1","b2")
beta <- c(3.126e-3, 2.537e-2)
cov  <- matrix(c(7.205e-06,-3.438e-06,-3.438e-06,2.718e-06),nrow=2)

ex1.a <- dose.distr(f, pars, beta, cov, cells=1811, dics=102, 
m.prior="normal", d.prior="uniform", prior.param=c(0, Inf))
summary(ex1.a)
plot(ex1.a)

radir documentation built on July 27, 2026, 9:10 a.m.